import { useCallback, useMemo } from "react";
import { Background, Controls, Edge, ReactFlow, Node, useNodesState, useEdgesState, Connection } from "@xyflow/react";
import * as node from "./node/";

import "@xyflow/react/dist/style.css";

import { Editor, Impl as EditorImpl } from "./context/Editor";

const nodeTypes = {
  fetch_ToshoListed: node.fetch.ToshoListed,
  present_TableDisplay: node.present.TableDisplay,
};
const initialNodes: Node[] = [
  {
    id: "n1",
    type: "fetch_ToshoListed",
    position: {x:0, y:0},
    data: {prime: true, standard: true, growth: true},
    deletable: false,
  },
  {
    id: "n2",
    type: "present_TableDisplay",
    position: {x:0, y:100},
    data: {},
  },
  {
    id: "n3",
    position: {x:0, y:200},
    data: {label: "hello"},
  },
];

export default function Screening() {
  const [nodes, setNodes, onNodesChange] = useNodesState(initialNodes);
  const [edges, setEdges, onEdgesChange] = useEdgesState([] as Edge[]);

  const editor = useMemo(()=>new EditorImpl(setNodes, setEdges, 100), []);

  const onConnect = useCallback(
    (conn: Connection)=>editor.connect(conn), []);
  const onDisconnect = useCallback(
    (conns: Edge[])=>editor.disconnect(conns.map((x)=>x as Connection)), []);
  const onNodesDelete = useCallback(
    (nodes: Node[])=>editor.remove(nodes.map((x)=>x.id)), []);

  return (
    <Editor.Provider value={editor}>
      <div style={{ position: "absolute", left: 0, right: 0, top: 0, bottom: 0 }}>
        <ReactFlow
          nodeTypes={nodeTypes}
          nodes={nodes}
          edges={edges}
          onNodesDelete={onNodesDelete}
          onNodesChange={onNodesChange}
          onEdgesDelete={onDisconnect}
          onEdgesChange={onEdgesChange}
          onConnect={onConnect}
          fitView
        >
          <Controls />
          <Background />
        </ReactFlow>
      </div>
    </Editor.Provider>
  );
}
