import { useTranslation } from "react-i18next";
import { ReactNode, useContext, useCallback } from "react";
import { NodeProps } from "@xyflow/react";

import style from "./style.module.scss";

import Editor from "../context/Editor";

type Params = {
  title: ReactNode,
  children: ReactNode,
  node: NodeProps,
};
export default function Base(p: Params) {
  const {t} = useTranslation();

  const editor = useContext(Editor);
  if (editor === undefined) {
    throw new Error("no editor context");
  }

  const onDelete = useCallback(()=>editor.remove([p.node.id]), [p.node]);

  return (
    <div className={style.node}>
      <div className={style.header}>
        <div className={style.title}>{p.title}</div>
        <div className={style.buttons}>
          <button onClick={onDelete} disabled={!p.node.deletable}>
            {t("pages.screening.nodes.base.remove")}
          </button>
        </div>
      </div>
      <div className={style.body}>
        {p.children}
      </div>
    </div>
  );
}
